var moment = require('./moment.js'), mustache = require('./mustache.js'), qrcode = require('./qrcode.js');

// Get correct appointment time considering slot
function getAppointmentTime(start, appointment, format) {
    let shiftStart = appointment.attendantRosterItem.task.startTimeSeconds,
        shiftEnd = appointment.attendantRosterItem.task.endTimeSeconds,
        slotIndex = appointment.slotIndex,
        slotTime = appointment.attendantRosterItem.slotTime,
        date = appointment.appointmentStart,
        tz = appointment.timeZone;
    let dateFormat = "YYYY-MM-DD HH:mm A";
    if(format === "time"){
        dateFormat = "HH:mm A";
    } else if(format === "date"){
        dateFormat = "YYYY-MM-DD";
    } else {
        dateFormat = "YYYY-MM-DD HH:mm:ss";
    }
    if(start === "start"){
        if (slotTime === 0){
            return moment.utc(date).utcOffset(tz/60).add(shiftStart, "second").format(dateFormat);
        } else {
            return moment.utc(date).utcOffset(tz/60).add(shiftStart + slotIndex * slotTime, "second").format(dateFormat);
        }
    } else {
        if(slotTime === 0){
            return moment.utc(date).utcOffset(tz/60).add(shiftEnd, "second").format(dateFormat);
        } else {
            return moment.utc(date).utcOffset(tz/60).add(shiftStart + (slotIndex + 1) * slotTime, "second").format(dateFormat);
        }
    }
}

function getDateTimeString(dateTime, format, timezone){
    if(timezone){
        return moment(dateTime).utcOffset(timezone/60).format(format);
    }
    return moment(dateTime).format(format);
}

// Generate qr code
function generateQrCodeDataURL(text) {
    console.log("Generating QR code for string: "+text);
    let typeNumber = 1, errorCorrectionLevel = "M";
    var qr = qrcode(typeNumber, errorCorrectionLevel);
    try {
        qr.addData(text); //type: "Alphanumeric"
        qr.make();
    } catch(e){
        console.log(e)
    }
    return qr.createDataURL(8, 4);
}

function getAppointmentDuration(slotTime, endTimeSeconds, startTimeSeconds) {
    if(slotTime === 0){
        slotTime = endTimeSeconds - startTimeSeconds
    }
    return moment.duration((slotTime), "seconds").humanize();
}

// return plain text string
function returnPlainText(text, params) {
    return mustache.render(text, params)
    //return text;
}

export {getAppointmentTime, getDateTimeString, returnPlainText, generateQrCodeDataURL, getAppointmentDuration};